/************************
 Three Dimensional Plotting Routines                    
*************************

   InitPlotting       - rotation and tilt angles
   InitPerspective    - observer location and distances
   MapCoordinates     - maps 3D space onto the 2D screen
   CartesianPlot      - plot a cartesian system point
   DrawLine3D	      - plots a line from 3D coordinates
*/

PixiAngle:
	/*Angle in degrees.
	512 segments in circle of 360 
	degrees
	*/
	Angle=(1800+ 						(Angle*5120))/3600
ret

CosD: PixiAngle /**/c=cos(Angle)
ret

SinD: PixiAngle/**/s=sin(Angle)
ret

InitPlotting://in: Angl, Tilt
/*Where Angl & Tilt are user
inputs. Angl is angle around z-axis.
Tilt is angle around off z-axis.
*/
  CentreX=0
  CentreY=0
	Angle=Angl SinD SinA=s 
	Angle=Angl CosD CosA=c
	Angle=Tilt SinD SinB=s
	Angle=Tilt CosD CosB=c 
  CosACosB=CosA*CosB//is 256^2 larger than supposed to be
  SinASinB=SinA*SinB//ibid
  CosASinB=CosA*SinB//ibid
  SinACosB=SinA*CosB//ibid
ret

InitPerspective:
	// x, y, z, m
//camera position in space
  Mx=x
  My=y
  Mz=z
  ds=m  //distance of camera from			 screen
ret

MapCoordinates://in:  X, Y, Z,
		//out:Xp, Yp
  Xt=256*Mx+X*CosA-Y*SinA
	Yt=256*My+(X*SinASinB					+Y*CosASinB)/256					+Z*CosB
	Zt=256*Mz+(X*SinACosB 					+Y*CosACosB)/256					-Z*SinB
	Xt/256 Yt/256 Zt/256 
    Xp=CentreX+(ds*Xt/Zt)
    Yp=CentreY-(ds*Yt/Zt)
ret

CartesianPlot3D:// X, Y, Z,  Color
	MapCoordinates//X,Y,Z, Xp,Yp
	dot(Xp, Yp, Color);
ret

DrawLine3D://in: Pnt1, Pnt2, Color
	X=Pnt1[0] Y=Pnt1[1] Z=Pnt1[2] 
	MapCoordinates
	Xp1=Xp Yp1=Yp
	X=Pnt2[0] Y=Pnt2[1] Z=Pnt2[2] 
	MapCoordinates
	line(Xp1, Yp1, Xp , Yp ,Color)
ret
